@@ -1,14 +1,14 @@
 mod2obspred <- function(model, obs.only = FALSE, x.only = FALSE) {
-  # version 2.0 (4 Mar 2025)
+  # version 2.1 (21 Jun 2025)
   
   if (x.only) {  # new (4 Mar 2025)
-    if (methods::is(model, "glm"))
+    if (inherits(model, "glm"))
       return(model$model[ , -1])
     
-    if (methods::is(model, "GBMFit"))
+    if (inherits(model, "GBMFit"))
       return(model$gbm_data_obj$x)
     
-    if (methods::is(model, "bart")) {
+    if (inherits(model, "bart")) {
       if (is.null(model$fit$data)) stop("'$fit$data' section not present in 'model'. Try running 'bart()' with 'keeptrees=TRUE'.")
       return(model$fit$data@x)  # requires model ran with keeptrees=TRUE
     }
@@ -17,11 +17,11 @@ mod2obspred <- function(model, obs.only = FALSE, x.only = FALSE) {
   }  # end if x.only
   
 
-  if (methods::is(model, "glm") || methods::is(model, "gam")) {
+  if (inherits(model, c("glm", "gam"))) {
     obs <- model$y
     if (!obs.only) pred <- model$fitted.values
 
-  } else if (methods::is(model, "gbm")) {
+  } else if (inherits(model, "gbm")) {
     obs <- model$data$y
     if (!obs.only) {
       pred <- suppressMessages(predict(model, type = "response"))  # checked same as:
@@ -29,7 +29,7 @@ mod2obspred <- function(model, obs.only = FALSE, x.only = FALSE) {
       # pred <- logit(model$fit)  # but this applies only to binary response
     }
 
-  } else if (methods::is(model, "GBMFit")) {
+  } else if (inherits(model, "GBMFit")) {
     obs <- model$gbm_data_obj$y
     if (!obs.only) {
       pred <- suppressMessages(predict(model, type = "response", newdata = model$gbm_data_obj$original_data, n.trees = length(model$trees)))  # checked same as:
@@ -37,11 +37,11 @@ mod2obspred <- function(model, obs.only = FALSE, x.only = FALSE) {
       # pred <- logit(model$fit)  # but this applies only to binary response
     }
 
-  } else if (methods::is(model, "randomForest")) {
+  } else if (inherits(model, "randomForest")) {
     obs <- as.integer(as.character(model$y))
     if (!obs.only) pred <- predict(model, type = "prob")[ , "1"]
 
-  } else if (methods::is(model, "bart")) {
+  } else if (inherits(model, "bart")) {
     if (is.null(model$fit$data)) stop("'$fit$data' section not present in 'model'. Try running 'bart()' with 'keeptrees=TRUE'.")
     obs <- model$fit$data@y  # requires model ran with keeptrees=TRUE
     if (!obs.only) pred <- fitted(model, type = "response")
